@@ -872,4 +872,14 @@ describe("referee-sinon", function() {
             assert.match(pass.args[0][0], "Expectation met");
         });
     });
+
+    describe("match from referee with sinon assert", function() {
+        it("matches", function() {
+            var fake = sinon.fake();
+
+            fake(42);
+
+            referee.assert.calledWith(fake, referee.match.number);
+        });
+    });
 });
